interface ServerStatus {
    host: string;
    port: number;
    ipv4: string;
    latency: number;
    description: any;
    version: {
        name: string;
        protocol: number;
    };
    players: {
        online: number;
        max: number;
    };
}
declare type Options = {
    host: string;
    port?: number;
    timeout?: number;
};
interface JavaEditionServerStatus extends ServerStatus {
    description: string | Record<string, any>;
    players: {
        online: number;
        max: number;
        sample?: {
            id: string;
            name: string;
        }[];
    };
    favicon?: string;
    srv?: {
        priority: number;
        weight: number;
        port: number;
        name: string;
    };
    [key: string]: any;
}
declare type JavaEditionOptions = Options & {
    noSrv?: boolean;
    protocol?: number;
};
interface LegacyJavaEditionServerStatus extends ServerStatus {
    description: string;
}
interface BedrockEditionServerStatus extends ServerStatus {
    description: string;
    serverId: string;
    gameId: string;
    payload: string[];
}
declare enum Server {
    LEGACY_B1_8_TO_1_3 = 0,
    LEGACY_1_4_TO_1_5 = 1,
    LEGACY_1_6 = 2,
    JAVA = 3,
    BEDROCK = 10
}
declare function ping(server: Server.JAVA, hostOrOpts: string | JavaEditionOptions): Promise<JavaEditionServerStatus>;
declare function ping(server: Server.LEGACY_1_6, hostOrOpts: string | Options): Promise<LegacyJavaEditionServerStatus>;
declare function ping(server: Server.LEGACY_1_4_TO_1_5, hostOrOpts: string | Options): Promise<LegacyJavaEditionServerStatus>;
declare function ping(server: Server.LEGACY_B1_8_TO_1_3, hostOrOpts: string | Options): Promise<LegacyJavaEditionServerStatus>;
declare function ping(server: Server.BEDROCK, hostOrOpts: string | Options): Promise<BedrockEditionServerStatus>;
export { Server, ServerStatus, Options, JavaEditionServerStatus, LegacyJavaEditionServerStatus, BedrockEditionServerStatus };
export default ping;
